const express = require('express')
const app = express()
const port = 3000
const db = require('better-sqlite3')('counter.db');
let counter_useless = 0;
let counter_unnecessary = 0;
let counter_pointless = 0;

db.exec(`CREATE TABLE IF NOT EXISTS "data" (
	"id"	INTEGER,
	"counter_useless"	INTEGER,
	"counter_unnecessary"	INTEGER,
	"counter_pointless"	INTEGER,
	PRIMARY KEY("id" AUTOINCREMENT)
);`)
db.exec(`INSERT into data(counter_pointless, counter_unnecessary, counter_useless)
 SELECT 0, 0, 0 WHERE NOT EXISTS(SELECT * FROM data WHERE id = 1);`)

function getCounters() {
	let data = db.prepare(`SELECT * FROM data`).get();
	counter_useless = data.counter_useless
	counter_unnecessary = data.counter_unnecessary
	counter_pointless = data.counter_pointless
	return {
		counter_useless: counter_useless,
		counter_unnecessary: counter_unnecessary,
		counter_pointless: counter_pointless
	}
}

function writeCounters(data) {
	let query = db.prepare(`UPDATE data SET counter_useless = ?, counter_unnecessary = ?, counter_pointless = ?`)
	counter_useless = data.counter_useless;
	counter_unnecessary = data.counter_unnecessary;
	counter_pointless = data.counter_pointless;
	query.run(counter_useless, counter_unnecessary, counter_pointless)
	return data
}

getCounters();

app.use(express.json())
app.use('/', express.static(__dirname + '/client/'))

app.get('/counter', (req, res) => {
	res.send(
		getCounters()
	)
});

app.post('/counter/:type', (req, res) => {
	const counterType = req.params;

	switch (counterType.type) {
		case "counter_useless":
			counter_useless++;
			break;
		case "counter_unnecessary":
			counter_unnecessary++;
			break;
		case "counter_pointless":
			counter_pointless++;
			break;
	}

	res.send(
		writeCounters({
			counter_useless: counter_useless,
			counter_unnecessary: counter_unnecessary,
			counter_pointless: counter_pointless
		})
	)
});
app.delete('/counter', (req, res) => {
	res.send(
		writeCounters({
			counter_useless: 0,
			counter_unnecessary: 0,
			counter_pointless: 0
		})
	)
})

app.listen(port, () => {
	console.log(`Counter listening at http://localhost:${port}`)
})